@@ -6,13 +6,7 @@ use Carp;
 use FabForce::DBDesigner4::XML;
 use FabForce::DBDesigner4::SQL;
 
-require Exporter;
-
-our @ISA         = qw(Exporter);
-our %EXPORT_TAGS = ();
-our @EXPORT_OK   = ();
-our @EXPORT      = qw();
-our $VERSION     = '0.07';
+our $VERSION     = '0.08';
 
 sub new{
   my ($class,%args) = @_;
